==> fine-web-0.0.1-20220919.091035-231.jar: beetlsql/base/BasEmprecordQuery.md <==
select
===
select @pageTag(){
				t.EMPRECORD_QUERY_ID,
		t.IS_ALL,
		getdicname('IS_OR_NOT',t.IS_ALL) IS_ALL_TEXT,
		t.SCOPE,
		(select group_concat(a.account_name) from bas_emp_account a where ','||t.SCOPE||','  like '%,user:'||a.account_id||',%') SCOPE_name,
		t.STATUS,
		t.REMARK,
		t.START_DATE,
		t.END_DATE,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.IS_USE
	 @}
from BAS_EMPRECORD_QUERY t
where t.is_use = 'Y'
@if(!isEmpty(search)){
and(
 upper(t.EMPRECORD_QUERY_ID) like #search#  ESCAPE '/'  or 
 upper(t.IS_ALL) like #search#  ESCAPE '/'  or 
 upper(t.SCOPE) like #search#  ESCAPE '/'  or 
 upper(t.STATUS) like #search#  ESCAPE '/'  or 
 upper(t.REMARK) like #search#  ESCAPE '/'  or 
 upper(t.START_DATE) like #search#  ESCAPE '/'  or 
 upper(t.END_DATE) like #search#  ESCAPE '/'  or 
 upper(t.CREATE_ACCOUNT) like #search#  ESCAPE '/'  or 
 upper(t.CREATE_TIME) like #search#  ESCAPE '/'  or 
 upper(t.MODIFY_ACCOUNT) like #search#  ESCAPE '/'  or 
 upper(t.MODIFY_TIME) like #search#  ESCAPE '/'  or 
 upper(t.IS_USE) like #search#  ESCAPE '/' 
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.EMPRECORD_QUERY_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}



checkIsHave
===
select *
  from BAS_EMPRECORD_QUERY t, bas_emp_account a
 where ','||#scope#||',' like '%,user:' || a.account_id || ',%'
   and t.is_use = 'Y'
   and ',' || t.scope || ',' like '%,user:' || a.account_id || ',%'
   and t.EMPRECORD_QUERY_ID <> #id# and t.status='Y'
   
   
findByAccountId
===
select *
  from BAS_EMPRECORD_QUERY t
 where ','||t.scope||',' like '%,user:' || #accountId# || ',%'
   and t.is_use = 'Y' and t.status='Y'

==> fine-web-0.0.2-20220913.113206-173.jar: beetlsql/base/BasEmprecordQuery.md <==
select
===
select @pageTag(){
				t.EMPRECORD_QUERY_ID,
		t.IS_ALL,
		getdicname('IS_OR_NOT',t.IS_ALL) IS_ALL_TEXT,
		t.SCOPE,
	    (
		SELECT
			group_concat(a.account_name)
		FROM
			bas_emp_account a
		WHERE
			CONCAT(',', t.SCOPE, ',') LIKE CONCAT(
				'%,user:',
				a.account_id,
				',%'
			)
	    ) SCOPE_name,
		t.STATUS,
		t.REMARK,
		t.START_DATE,
		t.END_DATE,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.IS_USE
	 @}
from BAS_EMPRECORD_QUERY t
where t.is_use = 'Y'
@if(!isEmpty(search)){
and(
 upper(t.EMPRECORD_QUERY_ID) like #search#  ESCAPE '/'  or 
 upper(t.IS_ALL) like #search#  ESCAPE '/'  or 
 upper(t.SCOPE) like #search#  ESCAPE '/'  or 
 upper(t.STATUS) like #search#  ESCAPE '/'  or 
 upper(t.REMARK) like #search#  ESCAPE '/'  or 
 upper(t.START_DATE) like #search#  ESCAPE '/'  or 
 upper(t.END_DATE) like #search#  ESCAPE '/'  or 
 upper(t.CREATE_ACCOUNT) like #search#  ESCAPE '/'  or 
 upper(t.CREATE_TIME) like #search#  ESCAPE '/'  or 
 upper(t.MODIFY_ACCOUNT) like #search#  ESCAPE '/'  or 
 upper(t.MODIFY_TIME) like #search#  ESCAPE '/'  or 
 upper(t.IS_USE) like #search#  ESCAPE '/' 
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.EMPRECORD_QUERY_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}



checkIsHave
===
select *
  from BAS_EMPRECORD_QUERY t, bas_emp_account a
 where  CONCAT(',',#scope#,',') like CONCAT('%,user:' , a.account_id , ',%')
   and t.is_use = 'Y'
   and  CONCAT(',' , t.scope , ',') like  CONCAT('%,user:' , a.account_id , ',%')
   and t.EMPRECORD_QUERY_ID <> #id# and t.status='Y'
   
   
findByAccountId
===
select *
  from BAS_EMPRECORD_QUERY t
 where  CONCAT(',',t.scope,',') like  CONCAT('%,user:' , #accountId# , ',%')
   and t.is_use = 'Y' and t.status='Y'
